Documentation
¶
Overview ¶
The keyword package implements functions for the reading and writing of ls-dyna .k files
Index ¶
- func Dump(w io.Writer, kwds *KeywordFile) error
- func WriteKeywordFile(kwd *KeywordFile, filename string) error
- type BoundaryTemperature
- type BoundaryTemperatureList
- type ButtLine
- type CombinedWeldLine
- type ConstrainedAdaptivity
- type ConstrainedAdaptivityList
- type ConstrainedGeneralizedWeld
- type ConstrainedGeneralizedWeldList
- type CrossFilletLine
- type DefineCurve
- type DefineCurveList
- type DefineCurvePoint
- type ElementBeam
- type ElementBeamList
- type ElementMass
- type ElementMassList
- type ElementShell
- type ElementShellList
- type ElementShellThickness
- type ElementShellThicknessList
- type ElementSolid
- type ElementSolidList
- type EmptyKeyword
- type FilletLine
- type Inertia
- type InitialStressShell
- type InitialStressShellHistoryLine
- type InitialStressShellIntegrationPoint
- type InitialStressShellList
- type InitialStressShellStressLine
- type InitialStressShellTensorLine
- type InitialStressShellThermalHistoryLine
- type InitialStressSolid
- type InitialStressSolidHistoryLine
- type InitialStressSolidIntegrationPoint
- type InitialStressSolidList
- type InitialStressSolidStressLine
- type InitialStressSolidTensorLine
- type InitialStressSolidThermalHistoryLine
- type InitialVelocityNode
- type InitialVelocityNodeList
- type KeywordFile
- type LoadRigidBody
- type LoadRigidBodyList
- type LoadThermalVariableNode
- type LoadThermalVariableNodeList
- type MatPiecewiseLinearPlasticity
- type MatPiecewiseLinearPlasticityList
- type MatRigid
- type MatRigidList
- type Node
- type NodeList
- type NodeMap
- type NodePairLine
- type Part
- type PartList
- type PartMap
- type SectionBeam
- type SectionBeamList
- type SectionShell
- type SectionShellAngle
- type SectionShellList
- type SectionSolid
- type SectionSolidList
- type SetNode
- type SetNodeColumnLine
- type SetNodeGeneralLine
- type SetNodeList
- type SetNodeListLine
- type SetPart
- type SetPartColumnLine
- type SetPartList
- type SetPartListLine
- type SetShell
- type SetShellColumnLine
- type SetShellGeneralLine
- type SetShellList
- type SetShellListLine
- type SpotLine
- type UnknownList
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Dump ¶
func Dump(w io.Writer, kwds *KeywordFile) error
Write a KeywordStruct to w (in the standard keyword format).
func WriteKeywordFile ¶
func WriteKeywordFile(kwd *KeywordFile, filename string) error
Types ¶
type BoundaryTemperature ¶
type BoundaryTemperatureList ¶
type BoundaryTemperatureList []*BoundaryTemperature
type CombinedWeldLine ¶
type ConstrainedAdaptivity ¶
type ConstrainedAdaptivity struct {
Sn, Mn1, Mn2 int64
}
type ConstrainedAdaptivityList ¶
type ConstrainedAdaptivityList []*ConstrainedAdaptivity
type ConstrainedGeneralizedWeld ¶
type ConstrainedGeneralizedWeld struct {
Id int64
Nsid int64
Cid int64
Filter int64
Window float64
Npr int64
Nprt int64
Spot *SpotLine
Fillet *FilletLine
Butt *ButtLine
CrossFillet *CrossFilletLine
NodePairs []*NodePairLine
CombinedWeldLines []*CombinedWeldLine
}
type ConstrainedGeneralizedWeldList ¶
type ConstrainedGeneralizedWeldList []*ConstrainedGeneralizedWeld
type CrossFilletLine ¶
type DefineCurve ¶
type DefineCurveList ¶
type DefineCurveList []*DefineCurve
type DefineCurvePoint ¶
type ElementBeam ¶
type ElementBeamList ¶
type ElementBeamList []*ElementBeam
type ElementMass ¶
type ElementMassList ¶
type ElementMassList []*ElementMass
type ElementShell ¶
func (*ElementShell) IsTri ¶
func (e *ElementShell) IsTri() bool
type ElementShellList ¶
type ElementShellList []*ElementShell
type ElementShellThickness ¶
ELEMENT_SHELL_THICKNESS
func (*ElementShellThickness) IsTri ¶
func (e *ElementShellThickness) IsTri() bool
type ElementShellThicknessList ¶
type ElementShellThicknessList []*ElementShellThickness
type ElementSolid ¶
func (*ElementSolid) IsPent ¶
func (e *ElementSolid) IsPent() bool
func (*ElementSolid) IsTet ¶
func (e *ElementSolid) IsTet() bool
type ElementSolidList ¶
type ElementSolidList []*ElementSolid
type EmptyKeyword ¶
type EmptyKeyword string
EmptyKeyword is used for keywords that have no content at all such as *KEYWORD and *END.
type FilletLine ¶
type InitialStressShell ¶
type InitialStressShellHistoryLine ¶
type InitialStressShellHistoryLine struct {
Hisv1, Hisv2, Hisv3, Hisv4, Hisv5, Hisv6, Hisv7, Hisv8 float64
}
type InitialStressShellIntegrationPoint ¶
type InitialStressShellIntegrationPoint struct {
StressLine *InitialStressShellStressLine
HistoryLines []*InitialStressShellHistoryLine
TensorLines []*InitialStressShellTensorLine
}
type InitialStressShellList ¶
type InitialStressShellList []*InitialStressShell
type InitialStressShellStressLine ¶
type InitialStressShellStressLine struct {
T, Sigxx, Sigyy, Sigzz, Sigxy, Sigyz, Sigzx, Eps float64
}
type InitialStressShellTensorLine ¶
type InitialStressShellTensorLine struct {
Tenxx, Tenyy, Tenzz, Tenxy, Tenyz, Tenzx float64
}
type InitialStressShellThermalHistoryLine ¶
type InitialStressShellThermalHistoryLine struct {
Thhsv1, Thhsv2, Thhsv3, Thhsv4, Thhsv5 float64
}
type InitialStressSolid ¶
type InitialStressSolidHistoryLine ¶
type InitialStressSolidHistoryLine struct {
Hisv1, Hisv2, Hisv3, Hisv4, Hisv5, Hisv6, Hisv7, Hisv8 float64
}
type InitialStressSolidIntegrationPoint ¶
type InitialStressSolidIntegrationPoint struct {
StressLine *InitialStressSolidStressLine
HistoryLines []*InitialStressSolidHistoryLine
TensorLines []*InitialStressSolidTensorLine
}
type InitialStressSolidList ¶
type InitialStressSolidList []*InitialStressSolid
type InitialStressSolidStressLine ¶
type InitialStressSolidStressLine struct {
Sigxx, Sigyy, Sigzz, Sigxy, Sigyz, Sigzx, Eps float64
}
type InitialStressSolidTensorLine ¶
type InitialStressSolidTensorLine struct {
Tenxx, Tenyy, Tenzz, Tenxy, Tenyz, Tenzx float64
}
type InitialStressSolidThermalHistoryLine ¶
type InitialStressSolidThermalHistoryLine struct {
Thhsv1, Thhsv2, Thhsv3, Thhsv4, Thhsv5 float64
}
type InitialVelocityNode ¶
type InitialVelocityNodeList ¶
type InitialVelocityNodeList []*InitialVelocityNode
type KeywordFile ¶
type KeywordFile struct {
// Every type included as a member of this struct should implement
// the keywordContainer interface.
Keyword EmptyKeyword // Must be first.
Title UnknownList
Parameter UnknownList
Part PartList
PartAdaptiveFailure UnknownList
PartModes UnknownList
PartSensor UnknownList
PartMove UnknownList
BoundarySpcNode UnknownList
DefineCurve DefineCurveList
LoadRigidBody LoadRigidBodyList
LoadThermalVariableNode LoadThermalVariableNodeList
SectionBeam SectionBeamList
SectionShell SectionShellList
SectionSolid SectionSolidList
SetNode SetNodeList
SetShell SetShellList
SetPart SetPartList
BoundaryTemperature BoundaryTemperatureList
Node NodeList
MatRigid MatRigidList
MatPiecewiseLinearPlasticity MatPiecewiseLinearPlasticityList
InitialVelocityNode InitialVelocityNodeList
InitialStressShell InitialStressShellList
InitialStressSolid InitialStressSolidList
ConstrainedAdaptivity ConstrainedAdaptivityList
ElementMass ElementMassList
ElementBeam ElementBeamList
ElementShell ElementShellList
ElementShellThickness ElementShellThicknessList
InitialStressBeam UnknownList
InitialStrainShell UnknownList
InitialStrainSolid UnknownList
ElementSolid ElementSolidList
ConstrainedGeneralizedWeld ConstrainedGeneralizedWeldList
Unknown UnknownList // Unparsable sections will pass through verbatim.
End EmptyKeyword // Must be last.
}
This struct represents and entire keyword file.
func Parse ¶
func Parse(r io.Reader, verbose bool) (*KeywordFile, error)
Parse a KeywordFile from r.
func ReadKeywordFile ¶
func ReadKeywordFile(filename string) (*KeywordFile, error)
func ReadKeywordFileB ¶
func ReadKeywordFileB(filename string, verbose bool) (*KeywordFile, error)
func (*KeywordFile) Clear ¶
func (k *KeywordFile) Clear(name string)
func (*KeywordFile) CpContainer ¶
func (k *KeywordFile) CpContainer(inname string, k2 *KeywordFile) error
type LoadRigidBody ¶
type LoadRigidBodyList ¶
type LoadRigidBodyList []*LoadRigidBody
type LoadThermalVariableNode ¶
type LoadThermalVariableNodeList ¶
type LoadThermalVariableNodeList []*LoadThermalVariableNode
type MatPiecewiseLinearPlasticityList ¶
type MatPiecewiseLinearPlasticityList []*MatPiecewiseLinearPlasticity
type MatRigidList ¶
type MatRigidList []*MatRigid
type NodePairLine ¶
Used with CROSS_FILLET read in Npr of the following
type SectionBeam ¶
type SectionBeamList ¶
type SectionBeamList []*SectionBeam
type SectionShell ¶
type SectionShellAngle ¶
type SectionShellAngle struct {
B [8]float64
}
type SectionShellList ¶
type SectionShellList []*SectionShell
type SectionSolidList ¶
type SectionSolidList []*SectionSolid
type SetNode ¶
type SetNode struct {
Title string
Sid int64
Da1 float64
Da2 float64
Da3 float64
Da4 float64
Solv string
BlankLines []*SetNodeListLine
ListLines []*SetNodeListLine
ColumnLines []*SetNodeColumnLine
ListGenerateLines []*SetNodeListLine
GeneralLines []*SetNodeGeneralLine
ListSmoothLines []*SetNodeListLine
}
type SetNodeColumnLine ¶
type SetNodeGeneralLine ¶
type SetNodeList ¶
type SetNodeList []*SetNode
type SetNodeListLine ¶
type SetNodeListLine struct {
N [8]int64
}
type SetPart ¶
type SetPart struct {
Title string
Sid int64
Da1 float64
Da2 float64
Da3 float64
Da4 float64
Solv string
BlankLines []*SetPartListLine
ListLines []*SetPartListLine
ColumnLines []*SetPartColumnLine
ListGenerateLines []*SetPartListLine
}
type SetPartColumnLine ¶
type SetPartList ¶
type SetPartList []*SetPart
type SetPartListLine ¶
type SetPartListLine struct {
P [8]int64
}
type SetShell ¶
type SetShell struct {
Title string
Sid int64
Da1 float64
Da2 float64
Da3 float64
Da4 float64
BlankLines []*SetShellListLine
ListLines []*SetShellListLine
ColumnLines []*SetShellColumnLine
ListGenerateLines []*SetShellListLine
GeneralLines []*SetShellGeneralLine
}
type SetShellColumnLine ¶
type SetShellGeneralLine ¶
type SetShellList ¶
type SetShellList []*SetShell
type SetShellListLine ¶
type SetShellListLine struct {
Eid [8]int64
}
type UnknownList ¶
type UnknownList [][]byte
This field type is used to save unknown input keywords so they can be written back out unchanged when we write the file.
Source Files
¶
- boundary_temperature.go
- constrained_adaptivity.go
- constrained_generalized_weld.go
- define_curve.go
- doc.go
- dump.go
- element_beam.go
- element_mass.go
- element_shell.go
- element_solid.go
- field.go
- initial_stress_shell.go
- initial_stress_solid.go
- initial_velocity.go
- keyword.go
- load_rigid_body.go
- load_thermal_variable_node.go
- mat_piecewise_linear_plasticity.go
- mat_rigid.go
- node.go
- parse.go
- part.go
- section_beam.go
- section_shell.go
- section_solid.go
- set_node.go
- set_part.go
- set_shell.go
Click to show internal directories.
Click to hide internal directories.